% -------------------------------------------------------------------------
% Replication of Figures 3, 4, 5, 6 and Appendix Figure D3
% Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
% Code based on the original work from:
% Ramey and Zubairy (2018) "Government Spending Multipliers in Good Times 
%  and in Bad: Evidence from U.S. Historical Data"
% -------------------------------------------------------------------------

clear
close all
clc

dat = xlsread('RZDAT.xlsx', 'rzdat'); % US data
DATE_long   = dat(:,1);
t1=find(DATE_long==1889.75);
t2=find(DATE_long==2015.75);
dat=dat(t1:t2,:);
DATE        = dat(:,1);

nomGOV          = dat(:,2);
nomGDP          = dat(:,3);
deflator        = dat(:,4);
population      = dat(:,5);
rec             = dat(:,6);
unemp           = dat(:,7);
news_original   = dat(:,8);
realGDP         = dat(:,9);
potentialgdp    = dat(:,15);


% Creating the state indicador (code from Ramey-Zubairy 2018)
threshold=6.5;
rrr=find(unemp>=threshold); 
rrrn=rrr+1; %Since unemployment above threshold in the previous period is the criterion
if rrrn(end)==length(unemp)+1
    rrrn=rrrn(1:end-1);
else
    rrrn=rrrn;
end
fu=zeros(size(unemp));
fu(rrrn)=1; % This is the dummy variable that defines the two states
size(rrr)/size(unemp)
    
STATE           = fu;

for t=2:size(news_original,1)
    Ramey_news(t,1)= news_original(t,1)./(deflator(t-1,1).*potentialgdp(t-1,1));
end

% Define main variables
Y  = realGDP./potentialgdp;%(deflator.*population);
G  = nomGOV./(deflator.*potentialgdp);

% Some parameters
SAVE      = 1;
secondCI  = 0;
hor=21;
P = 4;
F = 20; % number of forwards
shock = Ramey_news(P+1:end);

% Other variables
xlags = lagmatrix([G Y Ramey_news],1:P);
xlags = xlags(P+1:end,:);

fSTATE = lagmatrix(STATE,-F:-1); fSTATE = fliplr(fSTATE);

% TRIM all variables to make the number of observation comparabale
Y = Y(P+1:end-F,:);
G = G(P+1:end-F,:);
xlags = xlags(1:end-F,:);
shock = shock(1:end-F,:);
STATE = STATE(P+1:end-F,:);
fSTATE = fSTATE(P+1:end-F,:);

constant= ones(length(xlags),1);


% _________________________________________________________________________
%
% LINEAR ESTIMATION
%%
x=[constant, shock, xlags];

rpos=2; %position of the shock
[r,nn]=size(x);

% GDP
for i=1:hor
        yy=Y(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    se(:,i)=results.se;
    regGDPlin(:,i)=b;
    confidenceGDPlin(:,:,i)=bint;
    confidenceGDPlin_H(:,:,i)=bintH;
end
confidenceGDPlin=reshape(confidenceGDPlin,2*nn,hor);
confidenceGDPlin_H=reshape(confidenceGDPlin_H,2*nn,hor);
linGDP=[regGDPlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% GOV
for i=1:hor
        yy=G(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    regGOVlin(:,i)=b;
    se(:,i)=results.se';
    confidenceGOVlin(:,:,i)=bint;
    confidenceGOVlin_H(:,:,i)=bintH;
end
confidenceGOVlin=reshape(confidenceGOVlin,2*nn,hor);
confidenceGOVlin_H=reshape(confidenceGOVlin_H,2*nn,hor);
linGOV=[regGOVlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% _________________________________________________________________________
%
% LINEAR ESTIMATION WITH ***FORWARDS***
%%
news_forwards = lagmatrix(Ramey_news,-F:-1); news_forwards = fliplr(news_forwards);
news_forwards = news_forwards(P+1:end-F,:);
x=[constant, shock, xlags];

%rpos=2; %position of the shock
[r_per,nn_per]=size([x news_forwards]);
bint = zeros(nn_per,2);
bint_H = zeros(nn_per,2);
% GDP
for i=1:hor
        yy=Y(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end       
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGDPper(1:size(b,1),i)=b;
    confidenceGDPper(1:size(bint,1),:,i)=bint;
    confidenceGDPper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceGDPper=reshape(confidenceGDPper,2*nn_per,hor);
confidenceGDPper_H=reshape(confidenceGDPper_H,2*nn_per,hor);
perGDP=[regGDPper(rpos,:);se(rpos,:)];
clear b bint bintH se

% GOV
for i=1:hor
        yy=G(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGOVper(1:size(b,1),i)=b;
    confidenceGOVper(1:size(bint,1),:,i)=bint;
    confidenceGOVper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceGOVper=reshape(confidenceGOVper,2*nn_per,hor);
confidenceGOVper_H=reshape(confidenceGOVper_H,2*nn_per,hor);
perGOV=[regGOVper(rpos,:);se(rpos,:)];
clear b bint bintH se

    multiplier = cumsum(regGDPlin(rpos,:)) ./ cumsum(regGOVlin(rpos,:));
    multiplier_per = cumsum(regGDPper(rpos,:)) ./ cumsum(regGOVper(rpos,:));
    multtable = [multiplier([1 4 8 12]) max(multiplier)];

%% FIGURES

colorscheme = 0;

if colorscheme == 0 % GREY
    colorline = 'black';
    ColCI1 = [.85 0.85 0.85] ;  %Low CI
    ColCI2 = [.60 0.60 0.60];   %High CI darker
elseif colorscheme == 1 % BLUE
    navyblue = [19,30,66]/255;
    colorline = navyblue;
    ColCI1 = [213 235 255]/255; % 
    ColCI2 = [114 160 193]/255; % 
elseif colorscheme == 2 % RED
    redix = [184,4,4]/255;
    colorline = redix;
    ColCI1 = [240 180 186]/255; %
    ColCI2 = [237 111 123]/255; % darker
end

LINWIDTH = 3;

    figure
    hold on
    plot(0:1:hor-1,multiplier,'Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplier_per,'Color','red','Linewidth',LINWIDTH)
    axis([0 hor-1  0.5 1.3])
    ylabel('cumulative multiplier')
    xlabel('quarter')
    if SAVE  == 1
    print('-depsc2','Figure 4')
    end


figure
subplot(1,2,1);
hold on
box on
title(['GDP'])
h1=ciplot( confidenceGDPlin(rpos,:), confidenceGDPlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGDPlin_H(rpos,:), confidenceGDPlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGDPlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGDPper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGDPper(rpos,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGDPper(rpos+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(1,2,2);
hold on
box on
title(['GOV'])
h1=ciplot( confidenceGOVlin(rpos,:), confidenceGOVlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGOVlin_H(rpos,:), confidenceGOVlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGOVlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGOVper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGOVper(rpos,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGOVper(rpos+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);

hold on
xlabel('quarter')
hline(0,'k-');
hold off

if SAVE  == 1
print('-depsc2','Figure 3')
end

% _________________________________________________________________________
%
% NON-LINEAR ESTIMATION
%%                                          ];

% Define the dummy matrices
STATEk=kron(STATE,ones(1,size(xlags,2)));

clear x;
x=[constant, STATE, (1-STATE).*shock, STATE.*shock,  STATEk.*xlags (1-STATEk).*xlags, ];

rpos=3; %position of the shock
[r,nn]=size(x);

clear regGDP regGOV regGDPper regGOVper;
% Estimation of GDP
for i=1:hor
        yy=Y(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    se(:,i)=results.se';
    regGDP(:,i)=b;
    confidenceGDP(:,:,i)=bint;
    confidenceGDP_H(:,:,i)=bintH;
end
confidenceGDP=reshape(confidenceGDP,2*nn,hor);
confidenceGDP_H=reshape(confidenceGDP_H,2*nn,hor);
stateaGDP=[regGDP(rpos,:);se(rpos,:)];
statebGDP=[regGDP(rpos+1,:);se(rpos+1,:)];
clear b bint bintH se

% Estimation of GOV
for i=1:hor
        yy=G(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    se(:,i)=results.se';
    regGOV(:,i)=b;
    confidenceGOV(:,:,i)=bint;
    confidenceGOV_H(:,:,i)=bintH;
    
end
confidenceGOV=reshape(confidenceGOV,2*nn,hor);
confidenceGOV_H=reshape(confidenceGOV_H,2*nn,hor);
stateaGOV=[regGOV(rpos,:);se(rpos,:)];
statebGOV=[regGOV(rpos+1,:);se(rpos+1,:)];
clear b bint bintH se

% _________________________________________________________________________
%
% NON-LINEAR ESTIMATION WITH ***FORWARDS***
%%
news_forwards = lagmatrix(Ramey_news,-F:-1); news_forwards = fliplr(news_forwards);
news_forwards = news_forwards(P+1:end-F,:);


newsA = (1-STATE).*news_forwards;
newsB = STATE.*news_forwards;

clear x r_per nn_per confidenceGDPper confidenceGDPper_H confidenceGOVper confidenceGOVper_H ;
x=[constant, STATE, (1-STATE).*shock, STATE.*shock,  STATEk.*xlags (1-STATEk).*xlags, ];

[r_per,nn_per]=size([x newsA newsB ]);
bint = zeros(nn_per,2);
bint_H = zeros(nn_per,2);

rpos_per=3; %position of the shock

% Estimation of GDP
for i=1:hor
        yy=Y(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:i-1) newsB(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:F) newsB(1:end-i+1,1:F)],i);    
        end       
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGDP_per(1:size(b,1),i)=b;
    confidenceGDP_per(1:size(bint,1),:,i)=bint;
    confidenceGDP_H_per(1:size(bintH,1),:,i)=bintH;
end
confidenceGDP_per=reshape(confidenceGDP_per,2*nn_per,hor);
confidenceGDP_H_per=reshape(confidenceGDP_H_per,2*nn_per,hor);
stateaGDP_per=[regGDP_per(rpos_per,:);se(rpos_per,:)];
statebGDP_per=[regGDP_per(rpos_per+1,:);se(rpos_per+1,:)];
clear b bint bintH se

bint = zeros(nn_per,2);
bint_H = zeros(nn_per,2);

% Estimation of GOV
for i=1:hor
        yy=G(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:i-1) newsB(1:end-i+1,1:i-1) ],i);
        else
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:F) newsB(1:end-i+1,1:F) ],i);    
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGOV_per(1:size(b,1),i)=b;
    confidenceGOV_per(1:size(bint,1),:,i)=bint;
    confidenceGOV_H_per(1:size(bintH,1),:,i)=bintH;
end
confidenceGOV_per=reshape(confidenceGOV_per,2*nn_per,hor);
confidenceGOV_H_per=reshape(confidenceGOV_H_per,2*nn_per,hor);
stateaGOV_per=[regGOV_per(rpos_per,:);se(rpos_per,:)];
statebGOV_per=[regGOV_per(rpos_per+1,:);se(rpos_per+1,:)];
clear b bint bintH se


% _________________________________________________________________________
%
% NON-LINEAR ESTIMATION WITH ***FORWARDS*** AND ALSO FORWARDS OF THE STATES
%%
news_forwards = lagmatrix(Ramey_news,-F:-1); news_forwards = fliplr(news_forwards);
news_forwards = news_forwards(P+1:end-F,:);


newsA = (1-STATE).*news_forwards;
newsB = STATE.*news_forwards;

clear x confidenceGDPper confidenceGDPper_H confidenceGOVper confidenceGOVper_H ;
x=[constant, STATE, (1-STATE).*shock, STATE.*shock,  STATEk.*xlags (1-STATEk).*xlags, ];%, 

[r_perstate,nn_perstate]=size([x newsA newsB fSTATE]);
bint = zeros(nn_perstate,2);
bint_H = zeros(nn_perstate,2);

rpos_per=3; %position of the shock %Same as before 

% Estimation of GDP
for i=1:hor
        yy=Y(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:i-1) newsB(1:end-i+1,1:i-1) fSTATE(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:F) newsB(1:end-i+1,1:F) fSTATE(1:end-i+1,1:F)],i);    
        end       
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se_STATE(1:size(results.se,1),i)=results.se;
    regGDP_per_STATE(1:size(b,1),i)=b;
    confidenceGDP_per_STATE(1:size(bint,1),:,i)=bint;
    confidenceGDP_H_per_STATE(1:size(bintH,1),:,i)=bintH;
end
confidenceGDP_per_STATE=reshape(confidenceGDP_per_STATE,2*nn_perstate,hor);
confidenceGDP_H_per_STATE=reshape(confidenceGDP_H_per_STATE,2*nn_perstate,hor);
stateaGDP_per_STATE=[regGDP_per_STATE(rpos_per,:);se_STATE(rpos_per,:)];
statebGDP_per_STATE=[regGDP_per_STATE(rpos_per+1,:);se_STATE(rpos_per+1,:)];
clear b bint bintH se

bint = zeros(nn_perstate,2);
bint_H = zeros(nn_perstate,2);

% Estimation of GOV
for i=1:hor
        yy=G(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:i-1) newsB(1:end-i+1,1:i-1) fSTATE(1:end-i+1,1:i-1)],i);

        else
        results=nwest(yy, [x(1:end-i+1,:) newsA(1:end-i+1,1:F) newsB(1:end-i+1,1:F) fSTATE(1:end-i+1,1:F)],i);    
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se_STATE(1:size(results.se,1),i)=results.se;
    regGOV_per_STATE(1:size(b,1),i)=b;
    confidenceGOV_per_STATE(1:size(bint,1),:,i)=bint;
    confidenceGOV_H_per_STATE(1:size(bintH,1),:,i)=bintH;
end
confidenceGOV_per_STATE=reshape(confidenceGOV_per_STATE,2*nn_perstate,hor);
confidenceGOV_H_per_STATE=reshape(confidenceGOV_H_per_STATE,2*nn_perstate,hor);
stateaGOV_perSTATE_STATE=[regGOV_per_STATE(rpos_per,:);se_STATE(rpos_per,:)];
statebGOV_perSTATE_STATE=[regGOV_per_STATE(rpos_per+1,:);se_STATE(rpos_per+1,:)];
clear b bint bintH se

% Nonlinear figures
colorscheme = 0 ;
if colorscheme == 0 % GREY
    colorline = 'black';
    ColCI1 = [.85 0.85 0.85] ;  %Low CI
    ColCI2 = [.60 0.60 0.60];   %High CI darker
elseif colorscheme == 1 % BLUE
    navyblue = [19,30,66]/255;
    colorline = navyblue;
    ColCI1 = [213 235 255]/255; % 
    ColCI2 = [114 160 193]/255; % 
elseif colorscheme == 2 % RED
    redix = [184,4,4]/255;
    colorline = redix;
    ColCI1 = [240 180 186]/255; %
    ColCI2 = [237 111 123]/255; % darker
end
green = [0.466, 0.674, 0.188];

figure
subplot(2,2,1);
hold on
box on
title(['GDP - EXPANSION'])
h1=ciplot( confidenceGDP(rpos,:), confidenceGDP(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGDP_H(rpos,:), confidenceGDP_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGDP(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGDP_per(rpos_per,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGDP_per(rpos_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGDP_per(rpos_per+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(2,2,2);
hold on
box on
title(['GOV - EXPANSION'])
h1=ciplot( confidenceGOV(rpos,:), confidenceGOV(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGOV_H(rpos,:), confidenceGOV_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGOV(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGOV_per(rpos_per,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGOV_per(rpos_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGOV_per(rpos_per+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(2,2,3);
hold on
box on
title(['GDP - RECESSION'])
h1=ciplot( confidenceGDP(rpos+1,:), confidenceGDP(rpos+1+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGDP_H(rpos+1,:), confidenceGDP_H(rpos+1+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGDP(rpos+1,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGDP_per(rpos_per+1,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGDP_per(rpos_per+1,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGDP_per(rpos_per+1+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(2,2,4);
hold on
box on
title(['GOV - RECESSION'])
h1=ciplot( confidenceGOV(rpos+1,:), confidenceGOV(rpos+1+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGOV_H(rpos+1,:), confidenceGOV_H(rpos+1+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGOV(rpos+1,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGOV_per(rpos_per+1,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGOV_per(rpos_per+1,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGOV_per(rpos_per+1+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
%ylabel('percent')
xlabel('quarter')
hline(0,'k-');
%axis([1 hor mi(1)-0.1 ma(1)+0.1])
hold off
    if SAVE  == 1
    print('-depsc2','Figure 5')
    end
   

%Multiplier
    multiplierA = cumsum(regGDP(rpos,:)) ./ cumsum(regGOV(rpos,:));
    multiplierA_per = cumsum(regGDP_per(rpos,:)) ./ cumsum(regGOV_per(rpos,:));
    multiplierA_per_STATE = cumsum(regGDP_per_STATE(rpos,:)) ./ cumsum(regGOV_per_STATE(rpos,:));
    multiplierB = cumsum(regGDP(rpos+1,:)) ./ cumsum(regGOV(rpos+1,:));
    multiplierB_per = cumsum(regGDP_per(rpos+1,:)) ./ cumsum(regGOV_per(rpos+1,:));
    multiplierB_per_STATE = cumsum(regGDP_per_STATE(rpos+1,:)) ./ cumsum(regGOV_per_STATE(rpos+1,:));
    
    
    figure
    hold on
    plot(0:1:hor-1,multiplierA,'Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierA_per,'Color','red','Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierA_per_STATE,'Color',green,'Linewidth',LINWIDTH)
        plot(0:1:hor-1,multiplierB,'--','Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierB_per,'-.','Color','red','Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierB_per_STATE,'-.','Color',green,'Linewidth',LINWIDTH)
    axis([0 hor-1  -2.2 1.3])
    hline(0,'k-');
    legend('EXP, no leads','EXP, with leads','EXP, with leads (fixed state)','REC, no leads','REC, with leads', 'REC, with leads (fixed state)', 'Location','southeast')
    ylabel('cumulative multiplier')
    xlabel('quarter')
    if SAVE  == 1
    print('-depsc2','Figure D3')
    end
    
        figure
    hold on
    plot(0:1:hor-1,multiplierA,'Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierA_per,'Color','red','Linewidth',LINWIDTH)
        plot(0:1:hor-1,multiplierB,'--','Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplierB_per,'-.','Color','red','Linewidth',LINWIDTH)
    axis([0 hor-1  -2.2 1.3])
    hline(0,'k-');
    legend('EXP, no leads','EXP, with leads','REC, no leads','REC, with leads','Location','southeast')
    ylabel('cumulative multiplier')
    xlabel('quarter')
    if SAVE  == 1
    print('-depsc2','Figure 6')
    end

