% -------------------------------------------------------------------------
% Replication of Figure 7 and Appendix Figure D4
% Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
% Code based on the original work from:
% Ramey and Zubairy (2018) "Government Spending Multipliers in Good Times 
%  and in Bad: Evidence from U.S. Historical Data"
% -------------------------------------------------------------------------

clear
close all
clc

dat = xlsread('RZDAT.xlsx', 'rzdat'); % US data
DATE_long   = dat(:,1);
t1=find(DATE_long==1890);
t2=find(DATE_long==2015.75);
dat=dat(t1:t2,:);
DATE        = dat(:,1);

nomGOV          = dat(:,2);
nomGDP          = dat(:,3);
deflator        = dat(:,4);
population      = dat(:,5);
rec             = dat(:,6);
unemp           = dat(:,7);
news_original   = dat(:,8);
realGDP         = dat(:,9);
potentialgdp    = dat(:,15);
tbill           = dat(:,27);
taxrevs         = dat(:,10);
deficit         = dat(:,11);
zlbdummy        = dat(:,13);

% Creating the state indicador
threshold=6.5;
rrr=find(unemp>=threshold); 
rrrn=rrr+1; %Since unemployment above threshold in the previous period is the criterion
if rrrn(end)==length(unemp)+1
    rrrn=rrrn(1:end-1);
else
    rrrn=rrrn;
end
fu=zeros(size(unemp));
fu(rrrn)=1; % This is the dummy variable that defines the two states
size(rrr)/size(unemp)
    
STATE           = fu;

for t=2:size(news_original,1)
    Ramey_news(t,1)= news_original(t,1)./(deflator(t-1,1).*potentialgdp(t-1,1));
end

% Define main variables
Y  = realGDP./potentialgdp;%(deflator.*population);
G  = nomGOV./(deflator.*potentialgdp);
Z  = unemp; 

% Some parameters
SAVE      = 1;
secondCI  = 0;
hor=21;
P = 4;
F = 20; % number of forwards
shock = Ramey_news(P+1:end);

thirdvar= Z; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Other variables
xlags = lagmatrix([G Y thirdvar Ramey_news],1:P);  %Include interest rates
xlags = xlags(P+1:end,:);

fSTATE = lagmatrix(STATE,-F:-1); fSTATE = fliplr(fSTATE);

% TRIM all variables to make the number of observation comparabale
Y = Y(P+1:end-F,:);
G = G(P+1:end-F,:);
R = thirdvar(P+1:end-F,:);
xlags = xlags(1:end-F,:);
shock = shock(1:end-F,:);
STATE = STATE(P+1:end-F,:);
fSTATE = fSTATE(P+1:end-F,:);

constant= ones(length(xlags),1);
%t=(1:length(xlags))';
%tsq=t.^2;
%tcube=t.^3;


% _________________________________________________________________________
%
% LINEAR ESTIMATION
%%
x=[constant, shock, xlags];

rpos=2; %position of the shock
[r,nn]=size(x);

% GDP
for i=1:hor
        yy=Y(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    se(:,i)=results.se;
    regGDPlin(:,i)=b;
    confidenceGDPlin(:,:,i)=bint;
    confidenceGDPlin_H(:,:,i)=bintH;
end
confidenceGDPlin=reshape(confidenceGDPlin,2*nn,hor);
confidenceGDPlin_H=reshape(confidenceGDPlin_H,2*nn,hor);
linGDP=[regGDPlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% GOV
for i=1:hor
        yy=G(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    regGOVlin(:,i)=b;
    se(:,i)=results.se';
    confidenceGOVlin(:,:,i)=bint;
    confidenceGOVlin_H(:,:,i)=bintH;
end
confidenceGOVlin=reshape(confidenceGOVlin,2*nn,hor);
confidenceGOVlin_H=reshape(confidenceGOVlin_H,2*nn,hor);
linGOV=[regGOVlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% Interest Rates
for i=1:hor
        yy=R(i:end);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    regRlin(:,i)=b;
    se(:,i)=results.se';
    confidenceRlin(:,:,i)=bint;
    confidenceRlin_H(:,:,i)=bintH;
end
confidenceRlin=reshape(confidenceRlin,2*nn,hor);
confidenceRlin_H=reshape(confidenceRlin_H,2*nn,hor);
linR=[regRlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% _________________________________________________________________________
%
% LINEAR ESTIMATION WITH ***FORWARDS***
%%
news_forwards = lagmatrix(thirdvar,-F:-1); news_forwards = fliplr(news_forwards);
news_forwards = news_forwards(P+1:end-F,:);
x=[constant, shock, xlags];%, news_forwards];

%rpos=2; %position of the shock
[r_per,nn_per]=size([x news_forwards]);
bint = zeros(nn_per,2);
bint_H = zeros(nn_per,2);
% GDP
for i=1:hor
        yy=Y(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end       
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGDPper(1:size(b,1),i)=b;
    confidenceGDPper(1:size(bint,1),:,i)=bint;
    confidenceGDPper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceGDPper=reshape(confidenceGDPper,2*nn_per,hor);
confidenceGDPper_H=reshape(confidenceGDPper_H,2*nn_per,hor);
perGDP=[regGDPper(rpos,:);se(rpos,:)];
clear b bint bintH se

% GOV
for i=1:hor
        yy=G(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGOVper(1:size(b,1),i)=b;
    confidenceGOVper(1:size(bint,1),:,i)=bint;
    confidenceGOVper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceGOVper=reshape(confidenceGOVper,2*nn_per,hor);
confidenceGOVper_H=reshape(confidenceGOVper_H,2*nn_per,hor);
perGOV=[regGOVper(rpos,:);se(rpos,:)];
clear b bint bintH se

% R
for i=1:hor
        yy=R(i:end);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regRper(1:size(b,1),i)=b;
    confidenceRper(1:size(bint,1),:,i)=bint;
    confidenceRper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceRper=reshape(confidenceRper,2*nn_per,hor);
confidenceRper_H=reshape(confidenceRper_H,2*nn_per,hor);
perR=[regRper(rpos,:);se(rpos,:)];
clear b bint bintH se

    multiplier = cumsum(regGDPlin(rpos,:)) ./ cumsum(regGOVlin(rpos,:));
    multiplier_per = cumsum(regGDPper(rpos,:)) ./ cumsum(regGOVper(rpos,:));
    multtable = [multiplier([1 4 8 12]) max(multiplier)];

%% FIGURES

colorscheme = 0;

if colorscheme == 0 % GREY
    colorline = 'black';
    ColCI1 = [.85 0.85 0.85] ;  %Low CI
    ColCI2 = [.60 0.60 0.60];   %High CI darker
elseif colorscheme == 1 % BLUE
    navyblue = [19,30,66]/255;
    colorline = navyblue;
    ColCI1 = [213 235 255]/255; 
    ColCI2 = [114 160 193]/255; 
elseif colorscheme == 2 % RED
    redix = [184,4,4]/255;
    colorline = redix;
    ColCI1 = [240 180 186]/255; %
    ColCI2 = [237 111 123]/255; % darker
end

LINWIDTH = 3;

    figure
    hold on
    plot(0:1:hor-1,multiplier,'Color',colorline,'Linewidth',LINWIDTH)
    plot(0:1:hor-1,multiplier_per,'Color','red','Linewidth',LINWIDTH)
    axis([0 hor-1  0.0 1.3])
    ylabel('cumulative multiplier')
    xlabel('quarter')
    if SAVE  == 1
    print('-depsc2','Figure 7')
    end

figure
subplot(1,3,1);
hold on
box on
title(['GDP'])
h1=ciplot( confidenceGDPlin(rpos,:), confidenceGDPlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGDPlin_H(rpos,:), confidenceGDPlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGDPlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGDPper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGDPper(rpos,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGDPper(rpos+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(1,3,2);
hold on
box on
title(['GOV'])
h1=ciplot( confidenceGOVlin(rpos,:), confidenceGOVlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceGOVlin_H(rpos,:), confidenceGOVlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regGOVlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regGOVper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceGOVper(rpos,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceGOVper(rpos+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off

subplot(1,3,3);
hold on
box on
title(['UNEMP'])
h1=ciplot( confidenceRlin(rpos,:), confidenceRlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( confidenceRlin_H(rpos,:), confidenceRlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, regRlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, regRper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, confidenceRper(rpos,:),'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor-1, confidenceRper(rpos+nn_per,:),'--','Color','red','Linewidth',LINWIDTH-1);
hold on
xlabel('quarter')
hline(0,'k-');
hold off


if SAVE  == 1
print('-depsc2','Figure D4')
end


