% -------------------------------------------------------------------------
% Replication of Figure B3 in
% Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
% -------------------------------------------------------------------------

clear; clc; close all;

H=21;
nsims   = 1000; 
y0      = 0;
rho     = 0.9;
nlagsY  = 1;
ymean   = 0;
B0      = 1.5;
B1      = 1;
trim    = 1;
F       = 20;
gamma   = 0.2;

saveFIG = 1; %1=save figures, 0=don't

% Generate empty matrices for the simulations:
IR_LP_per = zeros(nsims,H);
IR_LP_percor = zeros(nsims,H);
IR_LP_percorF = zeros(nsims,H);

for q=1:nsims
% Created measure of shocks
nobs=497;
X2=zeros(nobs,1);
for j=2:nobs
    if mod(j,50)==0
        X2(j,1)=100;
    else
        X2(j,1)= gamma*X2(j-1,1);
    end
end

% Load the actual Ramey-Zubairy news variable (Ramey News as % of trend GDP)
load RZdata
X = 100*Ramey_news_trend_GDP;
lagX = lagmatrix(X,1);
fwdX = lagmatrix(X,-1);
fwdXF = lagmatrix(X,-F:-1);

nobs = length(X);

% Generate outcome Y - variable when shock is NOT persistent
Y = zeros(nobs,1);
Y(1,1) = y0;
residual = randn(nobs,1);

for i=2:nobs
    Y(i,1) = (1-rho)*ymean + rho*Y(i-1,1) + B0*X(i,1)+ B1*lagX(i,1) + residual(i,1);
end
lagY = lagmatrix(Y,1); 

%Preparing matrices for estimation
XX = [ones(nobs,1) X lagX lagY]; XX = XX(trim+1:end,:);
YY = Y(trim+1:end,:);

%% LP-IRF with actual regressor
for i=1:H
    yy = YY(i:end); 
    xx = XX(1:end-i+1,:);
    LPcoef_per = xx\yy;
    LP_per(:,i)=LPcoef_per;
end
IR_LP_per(q,:) = LP_per(2,:);

%% LP-IRF with actual regressor but including 1 lead
XX_fwd = [XX fwdX(2:end)];
XX_fwd = XX_fwd(1:end-1,:); YY_fwd=YY(1:end-1,:); 
for i=1:H
    yy = YY_fwd(i:end); 
    xx = XX_fwd(1:end-i+1,:);
    LPcoef_per_cor = xx\yy;
    LP_percor(:,i)=LPcoef_per_cor;
end
IR_LP_percor(q,:) = LP_percor(2,:);

%% LP-IRF with actual regressor but including many leads
XX_fwdF = [XX fwdXF(2:end,:)];
XX_fwdF = XX_fwdF(1:end-F,:); YY_fwdF=YY(1:end-F,:); 
for i=1:H
    yy = YY_fwdF(i:end); 
    xx = XX_fwdF(1:end-i+1,:);
    LPcoef_per_corF = xx\yy;
    LP_percorF(:,i)=LPcoef_per_corF;
end
IR_LP_percorF(q,:) = LP_percorF(2,:);

end % End of simulationss

%% True IRF
IR_true = zeros(H,1);
IR_true(1,:)  = B0;
IR_true(2,:)  = rho*IR_true(1,:) + B1;
for i = 3:H
    IR_true(i,:) = rho*IR_true(i-1,:);
end

IRav_LP_per = mean(IR_LP_per,1);
IRav_LP_percor = mean(IR_LP_percor,1);
IRav_LP_percorF = mean(IR_LP_percorF,1);

%% FIGURES -- 

navyblue = [19,30,66]/255;
gris= [.85 0.85 0.85];
redix = [184,4,4]/255;
green = [0.466, 0.674, 0.188];

figure
hold on
plot([0:H-1],IR_true,'k-','Color',navyblue,'Linewidth',3)
plot([0:H-1],IRav_LP_per,'b-','Color',redix,'Linewidth',3)
plot([0:H-1],IRav_LP_percor,'Color',green,'Linewidth',2.5);
plot([0:H-1],IRav_LP_percorF,'--','Color',gris,'Linewidth',3)
plot([0:H-1],zeros(1,H),'k')
legend('True IRF','LP - 0 leads','LP - 1 lead','LP - 20 leads')
if saveFIG == 1; print('-depsc2','Figure B3'); end
