/*****************************************************************************
				Replicating Figures C1 and C2 from 
	Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
	
*****************************************************************************/

*Requires installing: actest
* run: ssc install actest

cd "/type/your/path/here"

****************************************************************************
* Read in the data
****************************************************************************

clear
clear matrix
clear mata
set more off
use GLPdata.dta

xtset ifscode year

gen forward1 = F.size
gen forward2 = F2.size
gen forward3 = F3.size
gen forward4 = F4.size


keep ifscode year size g gcp OECD_dcapb forward*

bysort ifscode: gen cum_g = sum(g)
bysort ifscode: gen cum_gcp = sum(gcp)
bysort ifscode: gen cum_OECD_dcapb = sum(OECD_dcapb)
bysort year: gen trend=_n
bysort year: gen trend2=_n^2

sort ifscode year

local outcomes cum_g cum_gcp
local treatments size 
local controls L.size L.cum_g L.cum_gcp  

foreach outcome of varlist `outcomes' {
	foreach treatment of varlist `treatments' {
		preserve
		*drop last two years to keep the same sample wrt the estimation with forwards
		gen fsize0=F0.size
		gen fsize1=F1.size
		gen fsize2=F2.size
		gen fsize3=F3.size
		gen fsize4=F4.size
		gen fsize5=F5.size
		gen fsize6=F6.size
		gen fsize7=F7.size
		gen fsize8=F8.size
		gen fsize9=F9.size
		gen fsize10=F10.size
		tempname memhold
		tempfile file_results
		postfile `memhold' i blp_`outcome'_`treatment' se1 c1  using `file_results'.dta, replace
		
		forvalues i=0(1)10 { 
			xtreg F`i'.`outcome' `treatment' `controls'  i.year if fsize`i'!=., fe robust
			local blp_`outcome'_`treatment' = _b[`treatment'] 
			local se1 = _se[`treatment']
			local c1 = _b[_cons]
			post `memhold' (`i') (`blp_`outcome'_`treatment'') (`se1') (`c1') 
		}
		postclose `memhold'
		use `file_results'.dta, clear
		sort i

		gen lo2_`outcome'_`treatment'= blp_`outcome'_`treatment'-se1*1.645 
		gen hi2_`outcome'_`treatment'= blp_`outcome'_`treatment'+se1*1.645 

		gen lo1_`outcome'_`treatment'= blp_`outcome'_`treatment'-se1
		gen hi1_`outcome'_`treatment'= blp_`outcome'_`treatment'+se1
		
		twoway scatter blp_`outcome'_`treatment' i, connect(direct) ylabel(, nogrid) ///
		yline(0, lc(black)) mc(ebblue) lc(ebblue) || ///
		line lo2_`outcome'_`treatment' i, lc(ebblue) msize(small) || ///
		line hi2_`outcome'_`treatment' i, lc(ebblue) msize(small)  ///
		 legend(off) ///
		graphregion(color(white)) bgcolor(white) 
		
		export excel i blp_`outcome'_`treatment' lo2 hi2 lo1 hi1 using GLP_responses.xlsx, ///
		sheet("`outcome'_`treatment'") firstrow(variables) sheetmodify
		restore
	}	
}		

* Now include forwards:
foreach outcome of varlist `outcomes' {
	foreach treatment of varlist `treatments' {
		preserve
		gen fsize0=F0.size
		gen fsize1=F1.size
		gen fsize2=F2.size
		gen fsize3=F3.size
		gen fsize4=F4.size
		gen fsize5=F5.size
		gen fsize6=F6.size
		gen fsize7=F7.size
		gen fsize8=F8.size
		gen fsize9=F9.size
		gen fsize10=F10.size
		tempname memhold
		tempfile file_results
		postfile `memhold' i blp_`outcome'_`treatment' se1 c1  using `file_results'.dta, replace
		
		forvalues i=0(1)10 { 
				xtreg F`i'.`outcome' `treatment' `controls' F(0/`i').size  i.year if fsize`i'!=., fe robust
				local blp_`outcome'_`treatment' = _b[`treatment'] 
				local se1 = _se[`treatment']
				local c1 = _b[_cons]
				post `memhold' (`i') (`blp_`outcome'_`treatment'') (`se1') (`c1') 
		}
		postclose `memhold'
		use `file_results'.dta, clear
		sort i

		
		gen lo2_`outcome'_`treatment'= blp_`outcome'_`treatment'-se1*1.645 
		gen hi2_`outcome'_`treatment'= blp_`outcome'_`treatment'+se1*1.645 
		
		gen lo1_`outcome'_`treatment'= blp_`outcome'_`treatment'-se1
		gen hi1_`outcome'_`treatment'= blp_`outcome'_`treatment'+se1
		
		twoway scatter blp_`outcome'_`treatment' i, connect(direct) ylabel(, nogrid) ///
		yline(0, lc(black)) mc(ebblue) lc(ebblue) || ///
		line lo2_`outcome'_`treatment' i, lc(ebblue) msize(small) || ///
		line hi2_`outcome'_`treatment' i, lc(ebblue) msize(small)  ///
		 legend(off) ///
		graphregion(color(white)) bgcolor(white) 
		
		export excel i blp_`outcome'_`treatment' lo2 hi2 lo1 hi1 using GLP_responses.xlsx, ///
		sheet("`outcome'_`treatment'_FWD") firstrow(variables) sheetmodify
		restore
	}	
}	
