% -------------------------------------------------------------------------
% Replication of Figures C1 and C2 in
% Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
% -------------------------------------------------------------------------
clear
close all
clc

SAVE = 1;
hor  = 8;

dat=readmatrix('GLP_responses.xlsx','Sheet','cum_g_size');
dat = dat(1:hor+1,:);
DATE         = dat(:,1);      
GDPcum       = dat(:,2);
GDPcum_L     = dat(:,3);
GDPcum_H     = dat(:,4);
GDPcum_L_68  = dat(:,5);
GDPcum_H_68  = dat(:,6);

dat=readmatrix('GLP_responses.xlsx','Sheet','cum_g_size_FWD');
dat = dat(1:hor+1,:);
DATE         = dat(:,1);  
GDPcum_FWD   = dat(:,2);
GDPcum_FWD_L = dat(:,3);
GDPcum_FWD_H = dat(:,4);

dat=readmatrix('GLP_responses.xlsx','Sheet','cum_gcp_size');
dat = dat(1:hor+1,:);
DATE         = dat(:,1);  
CONcum       = dat(:,2);
CONcum_L     = dat(:,3);
CONcum_H     = dat(:,4);
CONcum_L_68  = dat(:,5);
CONcum_H_68  = dat(:,6);

dat=readmatrix('GLP_responses.xlsx','Sheet','cum_gcp_size_FWD');
dat = dat(1:hor+1,:);
DATE         = dat(:,1);
CONcum_FWD   = dat(:,2);
CONcum_FWD_L = dat(:,3);
CONcum_FWD_H = dat(:,4);


LINWIDTH = 3;


colorscheme = 0;

if colorscheme == 0 % GREY
    colorline = 'black';
    ColCI1 = [.85 0.85 0.85] ;  %Low CI
    ColCI2 = [.60 0.60 0.60];   %High CI darker
elseif colorscheme == 1 % BLUE
    navyblue = [19,30,66]/255;
    colorline = navyblue;
    ColCI1 = [213 235 255]/255; % 
    ColCI2 = [114 160 193]/255; % 
elseif colorscheme == 2 % RED
    redix = [184,4,4]/255;
    colorline = redix;
    ColCI1 = [240 180 186]/255; %
    ColCI2 = [237 111 123]/255; % darker
end

LINWIDTH = 3;


figure
hold on
box on
title(['GDP'])
h1=ciplot( GDPcum_L, GDPcum_H,0:1:hor,ColCI1);
hold on
plot(0:1:hor, GDPcum,'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor, GDPcum_FWD,'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor, GDPcum_FWD_L,'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor, GDPcum_FWD_H,'--','Color','red','Linewidth',LINWIDTH-1);
hold on
ylabel('percent')
xlabel('year')
hline(0,'k-');
hold off

if SAVE  == 1
print('-depsc2','Figure C1')
end

figure
hold on
box on
title(['CONSUMPTION'])
h1=ciplot( CONcum_L, CONcum_H,0:1:hor,ColCI1);
hold on
plot(0:1:hor, CONcum,'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor, CONcum_FWD,'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor, CONcum_FWD_L,'--','Color','red','Linewidth',LINWIDTH-1);
plot(0:1:hor, CONcum_FWD_H,'--','Color','red','Linewidth',LINWIDTH-1);
hold on
ylabel('percent')
xlabel('year')
hline(0,'k-');  
hold off
if SAVE  == 1
print('-depsc2','Figure C2')
end
