% -------------------------------------------------------------------------
% Replication of Figure C3
% Alloza, Gonzalo and Sanz (2024): Dynamic Effects of Persistent Shocks
% -------------------------------------------------------------------------

clear
close all
clc

%% LOAD DATA 
dat = xlsread('RRdata.xlsx', 'data'); % 
long_narrative = dat(:,2);
data =dat(9:end,:);

%% SET UP
% Some parameters
SAVE      = 1;
secondCI  = 1;
hor=12+1;
P = 0;
M = 0;
F = 12; % number of forwards

MT =1; %maxtrim

% Defining variables
Ylong = data(:,3);

shock= data(MT+1:end,2);
Y = Ylong(MT+1:end,:);

lagY = lagmatrix(Ylong,1);
lagY = lagY(MT+1:end,:);

xlags = lagmatrix([Ylong],1:P);
xlags = xlags(MT+1:end,:);

shocklags = lagmatrix(long_narrative,1:M);
shocklags = shocklags(9:end,:); % because we have 9 periods of 0s in narrative, but not GDP data
shocklags = shocklags(MT+1:end,:);

% TRIM all variables to make the number of observation comparabale
Y = Y(1:end-F,:);
xlags = xlags(1:end-F,:);
shock = shock(1:end-F,:);
shocklags = shocklags(1:end-F,:);
lagY = lagY(1:end-F,:);

constant= ones(length(shock),1);
t=(1:length(shock))';
tsq=t.^2;
tcube=t.^3;

%xlags = [];

% _________________________________________________________________________
%
% LINEAR ESTIMATION
%%
x=[constant, shock,shocklags, xlags, t];

rpos=2; %position of the shock
[r,nn]=size(x);

% Output 
for i=1:hor
    yy=(Y(i:end)-lagY(1:end-i+1))./lagY(1:end-i+1);
    results=nwest(yy, x(1:end-i+1,:),i);
    b=results.beta;
    bint(:,1)=b-(results.se*1.96);
    bint(:,2)=b+(results.se*1.96);
    bintH(:,1)=b-(results.se);
    bintH(:,2)=b+(results.se);
    se(:,i)=results.se';
    regGDPlin(:,i)=b;
    confidenceGDPlin(:,:,i)=bint;
    confidenceGDPlin_H(:,:,i)=bintH;
end
confidenceGDPlin=reshape(confidenceGDPlin,2*nn,hor);
confidenceGDPlin_H=reshape(confidenceGDPlin_H,2*nn,hor);
linGDP=[regGDPlin(rpos,:);se(rpos,:)];
clear b bint bintH se

% _________________________________________________________________________
%
% LINEAR ESTIMATION WITH ***FORWARDS***
%%

news_forwards = lagmatrix(data(:,2),-F:-1); news_forwards = fliplr(news_forwards);
news_forwards = news_forwards(MT+1:end-F,:);
x=[constant, shock,shocklags, xlags, t];

[r_per,nn_per]=size([x news_forwards]);
bint = zeros(nn_per,2);
bint_H = zeros(nn_per,2);

% GDP
for i=1:hor
    yy=(Y(i:end)-lagY(1:end-i+1))./lagY(1:end-i+1);
        if i==1
        results=nwest(yy, x(1:end-i+1,:),i);
        elseif i<=F
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:i-1)],i);    
        else
        results=nwest(yy, [x(1:end-i+1,:) news_forwards(1:end-i+1,1:F)],i);
        end   
    b=results.beta;
    bint(1:size(results.se,1),1)=b-(results.se*1.96);
    bint(1:size(results.se,1),2)=b+(results.se*1.96);
    bintH(1:size(results.se,1),1)=b-(results.se);
    bintH(1:size(results.se,1),2)=b+(results.se);
    se(1:size(results.se,1),i)=results.se;
    regGDPper(1:size(b,1),i)=b;
    confidenceGDPper(1:size(bint,1),:,i)=bint;
    confidenceGDPper_H(1:size(bintH,1),:,i)=bintH;
end
confidenceGDPper=reshape(confidenceGDPper,2*nn_per,hor);
confidenceGDPper_H=reshape(confidenceGDPper_H,2*nn_per,hor);
perGDP=[regGDPper(rpos,:);se(rpos,:)];
clear b bint bintH se


%% FIGURES

colorscheme = 0;

if colorscheme == 0 % GREY
    colorline = 'black';
    ColCI1 = [.85 0.85 0.85] ;  %Low CI
    ColCI2 = [.60 0.60 0.60];   %High CI darker
elseif colorscheme == 1 % BLUE
    navyblue = [19,30,66]/255;
    colorline = navyblue;
    ColCI1 = [213 235 255]/255; % 
    ColCI2 = [114 160 193]/255; % 
elseif colorscheme == 2 % RED
    redix = [184,4,4]/255;
    colorline = redix;
    ColCI1 = [240 180 186]/255; %
    ColCI2 = [237 111 123]/255; % darker
end

LINWIDTH = 3;

figure
hold on
box on
title(['GDP'])
h1=ciplot( 1*100*confidenceGDPlin(rpos,:), 1*100*confidenceGDPlin(rpos+nn,:),0:1:hor-1,ColCI1);
hold on
if secondCI==1
    h2= ciplot( 1*100*confidenceGDPlin_H(rpos,:), 1*100*confidenceGDPlin_H(rpos+nn,:),0:1:hor-1,ColCI2);
end
plot(0:1:hor-1, 1*100*regGDPper(rpos,:),'Color','red','Linewidth',LINWIDTH);
plot(0:1:hor-1, 1*100*regGDPlin(rpos,:),'Color',colorline,'Linewidth',LINWIDTH);
plot(0:1:hor-1, 1*100*confidenceGDPper(rpos,:),'--','Color','red','Linewidth',2);
plot(0:1:hor-1, 1*100*confidenceGDPper(rpos+nn_per,:),'--','Color','red','Linewidth',2);
hold on
ylabel('percent')
xlabel('quarter')
hline(0,'k-');
hold off


if SAVE  == 1
print('-depsc2','Figure C3')
end
